@@ -42,11 +42,14 @@ sed -i '' '/BEGIN/,/END/c\
 echo "Replacing Info.plist with $BUILD_VERSION"
 sed -i '' 's/<string>1.0<\/string>/<string>'$BUILD_VERSION'<\/string>/' Info.plist
 
-# "/Users/dannagle/Qt/6.4.1/macos/bin/qmake" PacketSender.pro -spec macx-clang CONFIG+=qtquickcompiler
-"/Users/dannagle/Qt/5.15.2/clang_64/bin/qmake" PacketSender.pro -spec macx-clang CONFIG+=x86_64
-make
-# /Users/dannagle/Qt/6.4.1/macos/bin/macdeployqt packetsender.app -appstore-compliant
-/Users/dannagle/Qt/5.15.2/clang_64/bin/macdeployqt packetsender.app -appstore-compliant
+# "/Users/dannagle/Qt/6.5.2/macos/bin/qmake" PacketSender.pro -spec macx-clang CONFIG+=qtquickcompiler
+"/Users/dannagle/Qt/6.5.2/macos/bin/qmake" PacketSender.pro -spec macx-clang CONFIG+=qtquickcompiler QMAKE_APPLE_DEVICE_ARCHS="x86_64 arm64"
+
+# /Users/dannagle/Qt/6.5.2/macos/bin/qmake /Users/dannagle/github/PacketSender/src/PacketSender.pro -spec macx-clang CONFIG+=qtquickcompiler QMAKE_APPLE_DEVICE_ARCHS="x86_64 arm64" && /usr/bin/make qmake_all
+
+make 
+# /Users/dannagle/Qt/6.5.2/macos/bin/macdeployqt packetsender.app -appstore-compliant
+/Users/dannagle/Qt/6.5.2/macos/bin/macdeployqt packetsender.app -appstore-compliant
 
 /usr/bin/codesign --option runtime --deep --force --sign  38E41C6C66CCA827750A10E26539E038F033E933 --timestamp packetsender.app
 mv packetsender.app PacketSender.app
