@@ -256,7 +256,12 @@ Engagez le Hash: </translation>
         <translation>Français</translation>
     </message>
     <message>
-        <location filename="../languagechooser.ui" line="170"/>
+        <location filename="../languagechooser.ui" line="187"/>
+        <source>Italiano</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../languagechooser.ui" line="206"/>
         <source>OK / Aceptar</source>
         <translation>OK / Aceptar</translation>
     </message>
@@ -386,7 +391,7 @@ Engagez le Hash: </translation>
     <message>
         <location filename="../mainwindow.ui" line="296"/>
         <location filename="../mainwindow.cpp" line="1073"/>
-        <location filename="../mainwindow.cpp" line="1728"/>
+        <location filename="../mainwindow.cpp" line="1731"/>
         <source>Send</source>
         <translation>Envoyer</translation>
     </message>
@@ -633,7 +638,7 @@ Voulez-vous lire les notes de lancement?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1029"/>
-        <location filename="../mainwindow.cpp" line="1267"/>
+        <location filename="../mainwindow.cpp" line="1270"/>
         <source>Multicast detected.</source>
         <translation>Multicast détecté.</translation>
     </message>
@@ -644,13 +649,13 @@ Voulez-vous lire les notes de lancement?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1049"/>
-        <location filename="../mainwindow.cpp" line="1289"/>
+        <location filename="../mainwindow.cpp" line="1292"/>
         <source>Broadcast with responses!</source>
         <translation>Diffusez avec des réponses!</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="1053"/>
-        <location filename="../mainwindow.cpp" line="1293"/>
+        <location filename="../mainwindow.cpp" line="1296"/>
         <source>You are sending a broadcast packet with responses enabled.
 
 This could cause traffic flooding. Continue?</source>
@@ -661,8 +666,8 @@ Cela pourrait provoquer une inondation du trafic. Continuer?</translation>
     <message>
         <location filename="../mainwindow.cpp" line="233"/>
         <location filename="../mainwindow.cpp" line="1067"/>
-        <location filename="../mainwindow.cpp" line="1329"/>
-        <location filename="../mainwindow.cpp" line="1935"/>
+        <location filename="../mainwindow.cpp" line="1332"/>
+        <location filename="../mainwindow.cpp" line="1938"/>
         <source>Resending</source>
         <translation>Renvoyer</translation>
     </message>
@@ -731,17 +736,17 @@ SSL attendu :</translation>
         <translation>Activer le support IPv6?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1271"/>
+        <location filename="../mainwindow.cpp" line="1274"/>
         <source>Join UDP multicast group?</source>
         <translation>Rejoindre le groupe multicast UDP?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1309"/>
+        <location filename="../mainwindow.cpp" line="1312"/>
         <source>Resend TCP with persistent connections!</source>
         <translation>Renvoyer le TCP avec des connexions persistantes!</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1313"/>
+        <location filename="../mainwindow.cpp" line="1316"/>
         <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 
 
 Uncheck persistent connection? (Recommended)</source>
@@ -750,123 +755,123 @@ Uncheck persistent connection? (Recommended)</source>
 Désactivez la connexion persistante ? (Recommandé)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1348"/>
-        <location filename="../mainwindow.cpp" line="1998"/>
+        <location filename="../mainwindow.cpp" line="1351"/>
+        <location filename="../mainwindow.cpp" line="2001"/>
         <source>No packets selected.</source>
         <translation>Aucun paquet sélectionné.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1352"/>
+        <location filename="../mainwindow.cpp" line="1355"/>
         <source>Select a packet.</source>
         <translation>Sélectionnez un paquet.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1391"/>
+        <location filename="../mainwindow.cpp" line="1394"/>
         <source>Invalid Address / DNS failed</source>
         <translation>Adresse non valide / échec du DNS</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1414"/>
+        <location filename="../mainwindow.cpp" line="1417"/>
         <source>Invalid Port</source>
         <translation>Port invalide</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1858"/>
+        <location filename="../mainwindow.cpp" line="1861"/>
         <source>Clear Log (0)</source>
         <translation>Effacer le registre (0)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1877"/>
+        <location filename="../mainwindow.cpp" line="1880"/>
         <source>Save Packet</source>
         <translation>Enregistrer le paquet</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1878"/>
+        <location filename="../mainwindow.cpp" line="1881"/>
         <source>Packet name:</source>
         <translation>Nom du paquet:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2002"/>
+        <location filename="../mainwindow.cpp" line="2005"/>
         <source>Clipboard unchanged.</source>
         <translation>Presse-papiers inchangé.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2063"/>
+        <location filename="../mainwindow.cpp" line="2066"/>
         <source>Save Traffic Log</source>
         <translation>Enregistrer le registre du trafic</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2064"/>
+        <location filename="../mainwindow.cpp" line="2067"/>
         <source>log (*.log)</source>
         <translation>registre (*.log)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2082"/>
+        <location filename="../mainwindow.cpp" line="2085"/>
         <source>TIME</source>
         <translation>Temp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2082"/>
+        <location filename="../mainwindow.cpp" line="2085"/>
         <source>From IP</source>
         <translation>De l&apos;IP</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2082"/>
+        <location filename="../mainwindow.cpp" line="2085"/>
         <source>From Port</source>
         <translation>Du port</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2082"/>
+        <location filename="../mainwindow.cpp" line="2085"/>
         <source>To IP</source>
         <translation>Vers IP</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2083"/>
+        <location filename="../mainwindow.cpp" line="2086"/>
         <source>To Port</source>
         <translation>Vers IP</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2083"/>
+        <location filename="../mainwindow.cpp" line="2086"/>
         <source>Method</source>
         <translation>Méthode</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2083"/>
+        <location filename="../mainwindow.cpp" line="2086"/>
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2258"/>
+        <location filename="../mainwindow.cpp" line="2261"/>
         <source>Import JSON</source>
         <translation>Importer JSON</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2260"/>
-        <location filename="../mainwindow.cpp" line="2327"/>
+        <location filename="../mainwindow.cpp" line="2263"/>
+        <location filename="../mainwindow.cpp" line="2330"/>
         <source>JSON db (*.json)</source>
         <translation>JSON db (*.json)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2284"/>
-        <location filename="../mainwindow.cpp" line="2421"/>
+        <location filename="../mainwindow.cpp" line="2287"/>
+        <location filename="../mainwindow.cpp" line="2424"/>
         <source>Found </source>
         <translation>Trouvé </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2284"/>
-        <location filename="../mainwindow.cpp" line="2421"/>
+        <location filename="../mainwindow.cpp" line="2287"/>
+        <location filename="../mainwindow.cpp" line="2424"/>
         <source> packets!</source>
         <translation> paquets!</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2288"/>
-        <location filename="../mainwindow.cpp" line="2425"/>
+        <location filename="../mainwindow.cpp" line="2291"/>
+        <location filename="../mainwindow.cpp" line="2428"/>
         <source>Import </source>
         <translation>Importer </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2288"/>
-        <location filename="../mainwindow.cpp" line="2425"/>
+        <location filename="../mainwindow.cpp" line="2291"/>
+        <location filename="../mainwindow.cpp" line="2428"/>
         <source> packets?
 
 Packet Sender will overwrite packets with the same name.</source>
@@ -875,90 +880,90 @@ Packet Sender will overwrite packets with the same name.</source>
 Le Packet Sender écrasera les paquets portant le même nom.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2291"/>
-        <location filename="../mainwindow.cpp" line="2312"/>
-        <location filename="../mainwindow.cpp" line="2428"/>
-        <location filename="../mainwindow.cpp" line="2449"/>
+        <location filename="../mainwindow.cpp" line="2294"/>
+        <location filename="../mainwindow.cpp" line="2315"/>
+        <location filename="../mainwindow.cpp" line="2431"/>
+        <location filename="../mainwindow.cpp" line="2452"/>
         <source>Import Cancelled</source>
         <translation>Importation annulée</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2299"/>
+        <location filename="../mainwindow.cpp" line="2302"/>
         <source>Import Finished</source>
         <translation>Importation terminée</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2305"/>
-        <location filename="../mainwindow.cpp" line="2442"/>
+        <location filename="../mainwindow.cpp" line="2308"/>
+        <location filename="../mainwindow.cpp" line="2445"/>
         <source>Not a database</source>
         <translation>Pas une base de données</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2309"/>
-        <location filename="../mainwindow.cpp" line="2446"/>
+        <location filename="../mainwindow.cpp" line="2312"/>
+        <location filename="../mainwindow.cpp" line="2449"/>
         <source>Found no packets in this file. It may not be a Packet Sender export</source>
         <translation>Je n&apos;ai trouvé aucun paquet dans ce fichier. Il se peut que ce ne soit pas une exportation de Packet Sender</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2326"/>
+        <location filename="../mainwindow.cpp" line="2329"/>
         <source>Save JSON</source>
         <translation>Sauvegarder JSON</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2348"/>
-        <location filename="../mainwindow.cpp" line="2481"/>
+        <location filename="../mainwindow.cpp" line="2351"/>
+        <location filename="../mainwindow.cpp" line="2484"/>
         <source>Export: </source>
         <translation>Exporter: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2352"/>
+        <location filename="../mainwindow.cpp" line="2355"/>
         <source>Could not save</source>
         <translation>Pas pu sauvegarder</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2356"/>
+        <location filename="../mainwindow.cpp" line="2359"/>
         <source>Could not open </source>
         <translation>Pas pu ouvrir </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2402"/>
-        <location filename="../mainwindow.cpp" line="2527"/>
+        <location filename="../mainwindow.cpp" line="2405"/>
+        <location filename="../mainwindow.cpp" line="2530"/>
         <source>Import File</source>
         <translation>Importer le fichier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2404"/>
-        <location filename="../mainwindow.cpp" line="2459"/>
+        <location filename="../mainwindow.cpp" line="2407"/>
+        <location filename="../mainwindow.cpp" line="2462"/>
         <source>INI db (*.ini)</source>
         <translation>INI db (*.ini)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2458"/>
+        <location filename="../mainwindow.cpp" line="2461"/>
         <source>Save File</source>
         <translation>Sauvegarder le ficher</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2529"/>
+        <location filename="../mainwindow.cpp" line="2532"/>
         <source>*.*</source>
         <translation>*.*</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2553"/>
+        <location filename="../mainwindow.cpp" line="2556"/>
         <source>Max size exceeded!</source>
         <translation>Taille maximale dépassée!</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2557"/>
+        <location filename="../mainwindow.cpp" line="2560"/>
         <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
         <translation>Le fichier HEX peut supporter jusqu&apos;à 10 922 octets. Les données ont été tronquées.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2563"/>
+        <location filename="../mainwindow.cpp" line="2566"/>
         <source>Loading </source>
         <translation>Chargement </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2563"/>
+        <location filename="../mainwindow.cpp" line="2566"/>
         <source> bytes</source>
         <translation> octets</translation>
     </message>
@@ -1630,17 +1635,17 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
 <context>
     <name>PreviewFilter</name>
     <message>
-        <location filename="../mainwindow.cpp" line="2722"/>
+        <location filename="../mainwindow.cpp" line="2725"/>
         <source>Multi-line editor</source>
         <translation>Éditeur multi-lignes</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2728"/>
+        <location filename="../mainwindow.cpp" line="2731"/>
         <source>Update</source>
         <translation>Mise à jour</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="2729"/>
+        <location filename="../mainwindow.cpp" line="2732"/>
         <source>Close</source>
         <translation>Fermer</translation>
     </message>
@@ -1649,6 +1654,7 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
     <name>QObject</name>
     <message>
         <location filename="../packet.cpp" line="266"/>
+        <location filename="../settings.cpp" line="44"/>
         <source>Send</source>
         <translation>Envoyer</translation>
     </message>
@@ -1657,6 +1663,56 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
         <source>Send &lt;b&gt;</source>
         <translation>Envoyer &lt;b&gt;</translation>
     </message>
+    <message>
+        <location filename="../settings.cpp" line="47"/>
+        <source>Name</source>
+        <translation>Nom</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="50"/>
+        <source>Resend</source>
+        <translation>Renvoyer</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="53"/>
+        <source>To Address</source>
+        <translation>À l&apos;adresse</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="56"/>
+        <source>To Port</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="59"/>
+        <source>Method</source>
+        <translation>Méthode</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="62"/>
+        <source>Request Path</source>
+        <translation>Demande de chemin</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="65"/>
+        <source>Time</source>
+        <translation>Temp</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="68"/>
+        <source>From IP</source>
+        <translation>de l&apos;IP</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="71"/>
+        <source>From Port</source>
+        <translation>Du port</translation>
+    </message>
+    <message>
+        <location filename="../settings.cpp" line="74"/>
+        <source>Error</source>
+        <translation>Erreur</translation>
+    </message>
 </context>
 <context>
     <name>Settings</name>
@@ -1876,7 +1932,7 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
     </message>
     <message>
         <location filename="../settings.ui" line="469"/>
-        <location filename="../settings.cpp" line="970"/>
+        <location filename="../settings.cpp" line="975"/>
         <source>Host</source>
         <translation>Hôte</translation>
     </message>
@@ -1892,7 +1948,7 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
     </message>
     <message>
         <location filename="../settings.ui" line="499"/>
-        <location filename="../settings.cpp" line="1041"/>
+        <location filename="../settings.cpp" line="1046"/>
         <source>HTTP Header</source>
         <translation>En-tête HTTP</translation>
     </message>
@@ -1914,7 +1970,6 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
     <message>
         <location filename="../settings.ui" line="555"/>
         <location filename="../settings.ui" line="583"/>
-        <location filename="../settings.cpp" line="46"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
@@ -1927,7 +1982,6 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
     <message>
         <location filename="../settings.ui" line="565"/>
         <location filename="../settings.ui" line="593"/>
-        <location filename="../settings.cpp" line="67"/>
         <source>From IP</source>
         <translation>de l&apos;IP</translation>
     </message>
@@ -2086,124 +2140,79 @@ En sélectionnant Non, de nouveaux identifiants seront générés et les donnée
         <translation>Documents en ligne</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="43"/>
-        <source>Send</source>
-        <translation>Envoyer</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="49"/>
-        <source>Resend</source>
-        <translation>Renvoyer</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="52"/>
-        <source>To Address</source>
-        <translation>À l&apos;adresse</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="55"/>
-        <source>To Port</source>
-        <translation>Au port</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="58"/>
-        <source>Method</source>
-        <translation>Méthode</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="61"/>
-        <source>Request Path</source>
-        <translation>Demande de chemin</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="64"/>
-        <source>Time</source>
-        <translation>Temp</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="70"/>
-        <source>From Port</source>
-        <translation>Du port</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="73"/>
-        <source>Error</source>
-        <translation>Erreur</translation>
-    </message>
-    <message>
-        <location filename="../settings.cpp" line="102"/>
+        <location filename="../settings.cpp" line="103"/>
         <source>Settings</source>
         <translation>Paramètres</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="354"/>
+        <location filename="../settings.cpp" line="359"/>
         <source>Bad IP.</source>
         <translation>Mauvaise IP</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="358"/>
+        <location filename="../settings.cpp" line="363"/>
         <source>Packet Sender cannot bind invalid IP </source>
         <translation>Packet Sender ne peut pas lier l&apos;IP invalide</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="372"/>
+        <location filename="../settings.cpp" line="377"/>
         <source>TCP and SSL non-zero port conflict.</source>
         <translation>Conflit de ports non nuls entre TCP et SSL.</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="376"/>
+        <location filename="../settings.cpp" line="381"/>
         <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
         <translation>Packet Sender ne peut pas lier TCP et SSL au même port.</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="721"/>
+        <location filename="../settings.cpp" line="726"/>
         <source>Open Directory</source>
         <translation>Répertoire ouvert</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="742"/>
+        <location filename="../settings.cpp" line="747"/>
         <source>Choose Cert</source>
         <translation>Choisissez un certificat</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="742"/>
+        <location filename="../settings.cpp" line="747"/>
         <source>Certs (*.pem)</source>
         <translation>Certificats (*.pem)</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="758"/>
+        <location filename="../settings.cpp" line="763"/>
         <source>Choose Key</source>
         <translation>Choisissez une clé</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="758"/>
+        <location filename="../settings.cpp" line="763"/>
         <source>Keys (*.key, *.pem)</source>
         <translation>Clés (*.key, *.pem)</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="970"/>
-        <location filename="../settings.cpp" line="1039"/>
+        <location filename="../settings.cpp" line="975"/>
+        <location filename="../settings.cpp" line="1044"/>
         <source>Key</source>
         <translation>Clé</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="970"/>
-        <location filename="../settings.cpp" line="1040"/>
+        <location filename="../settings.cpp" line="975"/>
+        <location filename="../settings.cpp" line="1045"/>
         <source>Value</source>
         <translation>Valeur</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="1035"/>
+        <location filename="../settings.cpp" line="1040"/>
         <source>UN/ClientID</source>
         <translation>UN/IDClient</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="1036"/>
+        <location filename="../settings.cpp" line="1041"/>
         <source>PW/Access</source>
         <translation>MP/Accès</translation>
     </message>
     <message>
-        <location filename="../settings.cpp" line="1037"/>
+        <location filename="../settings.cpp" line="1042"/>
         <source>HTTP Auth Header</source>
         <translation>En-tête d&apos;authentification HTTP</translation>
     </message>
